@@ -67,7 +67,7 @@ class Button:
         *,
         skip_if: Optional[Callable[["Menu"], bool]] = None,
         position: Optional[Position] = None,
-        lock: Optional[bool] = True
+        lock: Optional[bool] = True,
     ):
 
         self.emoji = _cast_emoji(emoji)
@@ -264,7 +264,7 @@ class Menu(metaclass=_MenuMeta):
         delete_message_after: bool = False,
         clear_reactions_after: bool = False,
         check_embeds: bool = False,
-        message: Optional[nextcord.Message] = None
+        message: Optional[nextcord.Message] = None,
     ):
 
         self.timeout = timeout
@@ -829,7 +829,7 @@ class ButtonMenu(Menu, nextcord.ui.View):
         clear_buttons_after: bool = False,
         disable_buttons_after: bool = False,
         *args,
-        **kwargs
+        **kwargs,
     ):
         Menu.__init__(self, timeout=timeout, *args, **kwargs)
         nextcord.ui.View.__init__(self, timeout=timeout)
